# yarm 

Yarm, yet another report maker.

Yarm makes it easy for you to create recurring reports by:

- Importing spreadsheets and CSVs
- Running SQL queries or Python code on this data
- Exporting the results to spreadsheets, CSVs, charts, and more
- All configured in a simple YAML file

## Coming soon...

Yarm is nearly at alpha, but it's not yet ready for release. Come back soon.
